@@ -5,6 +5,7 @@ def _load():
     global _ryaml
     if _ryaml is None:
         import ruamel.yaml as _ryaml
+
         from sr.comp.yaml_loader import add_time_constructor
         add_time_constructor(_ryaml.RoundTripLoader)
     return _ryaml
@@ -12,7 +13,7 @@ def _load():
 
 def load(yaml_file):
     ryaml = _load()
-    with open(yaml_file, 'r') as yf:
+    with open(yaml_file) as yf:
         return ryaml.load(yf, ryaml.RoundTripLoader, version=(1, 1))
 
 
